@@ -48,7 +48,7 @@ class Collection(Entity):
             # Select the collection by using python index.
             collections[1].edit(name='A New Collection Name')
         """
-        from labstep.entities.collection.repository import collectionRepository
+        import labstep.entities.collection.repository as collectionRepository
 
         return collectionRepository.editCollection(self, name, extraParams=extraParams)
 
