@@ -3,7 +3,9 @@
 # Author: Barney Walker <barney@labstep.com>
 
 from labstep.entities.deviceData.model import DeviceData
-from labstep.generic.shareableEntity.model import ShareableEntity
+from labstep.generic.entityWithMetadata.model import EntityWithMetadata
+from labstep.generic.entityWithSharing.model import EntityWithSharing
+from labstep.generic.entityWithComments.model import EntityWithComments
 from labstep.service.helpers import getTime
 
 
@@ -31,7 +33,7 @@ ALLOWED_FIELDS = {
 }
 
 
-class Device(ShareableEntity):
+class Device(EntityWithSharing, EntityWithMetadata, EntityWithComments):
     """
     Represents a Device on Labstep.
 
@@ -68,7 +70,7 @@ class Device(ShareableEntity):
             my_device = user.getDevice(17000)
             my_device.edit(name='A New Device Name')
         """
-        from labstep.entities.device.repository import deviceRepository
+        import labstep.entities.device.repository as deviceRepository
 
         return deviceRepository.editDevice(self, name, extraParams=extraParams)
 
@@ -83,7 +85,7 @@ class Device(ShareableEntity):
             my_device = user.getDevice(17000)
             my_device.delete()
         """
-        from labstep.entities.device.repository import deviceRepository
+        import labstep.entities.device.repository as deviceRepository
 
         return deviceRepository.editDevice(self, deleted_at=getTime())
 
@@ -133,7 +135,7 @@ class Device(ShareableEntity):
             metadata = device.addMetadata("Refractive Index",
                                                value="1.73")
         """
-        from labstep.entities.metadata.repository import metadataRepository
+        import labstep.entities.metadata.repository as metadataRepository
 
         return metadataRepository.addMetadataTo(
             self,
@@ -164,7 +166,7 @@ class Device(ShareableEntity):
             metadatas = my_device.getMetadata()
             metadatas[0].attributes()
         """
-        from labstep.entities.metadata.repository import metadataRepository
+        import labstep.entities.metadata.repository as metadataRepository
 
         return metadataRepository.getMetadata(self)
 
@@ -186,11 +188,11 @@ class Device(ShareableEntity):
         DeviceData
             A list of DeviceData objects.
         """
-        from labstep.generic.entity.repository import entityRepository
+        from labstep.generic.entity.repository import getEntities
 
         params = {"search_query": search_query,
                   "device_id": self.id, **extraParams}
-        return entityRepository.getEntities(self.__user__, DeviceData, count, params)
+        return getEntities(self.__user__, DeviceData, count, params)
 
     def addData(
         self,
@@ -234,15 +236,15 @@ class Device(ShareableEntity):
             data = device.addData("Temperature","numeric",
                                                number=173, unit='K')
         """
-        from labstep.generic.entity.repository import entityRepository
-        from labstep.entities.file.repository import fileRepository
+        from labstep.generic.entity.repository import newEntity
+        from labstep.entities.file.repository import newFile
 
         if fieldType not in FIELD_TYPES:
             msg = "Not a supported data type '{}'".format(fieldType)
             raise ValueError(msg)
 
         if filepath is not None:
-            file_id = fileRepository.newFile(self.__user__, filepath).id
+            file_id = newFile(self.__user__, filepath).id
         else:
             file_id = None
 
@@ -269,4 +271,4 @@ class Device(ShareableEntity):
             **extraParams,
         }
 
-        return entityRepository.newEntity(self.__user__, DeviceData, params)
+        return newEntity(self.__user__, DeviceData, params)
