@@ -5,7 +5,7 @@
 import labstep.entities.file.repository as fileRepository
 import labstep.generic.entity.repository as entityRepository
 from labstep.generic.entityList.model import EntityList
-from labstep.service.helpers import handleDate, handleString
+from labstep.service.helpers import formatDate, handleDate, handleString
 from labstep.entities.experimentDataField.model import ExperimentDataField
 from labstep.entities.experimentProtocol.model import ExperimentProtocol
 from labstep.entities.resource.model import Resource
@@ -90,10 +90,10 @@ def getDataFieldValue(dataField):
     if dataField.type == 'date':
         if dataField.date is None:
             return None
-        return dataField.date[:10]
+        return formatDate(dataField.date, time=False)
 
     if dataField.type == 'datetime':
-        return dataField.date
+        return formatDate(dataField.date)
 
     if dataField.type == 'options':
         if dataField.options is None:
