@@ -4,6 +4,7 @@
 
 import labstep.entities.file.repository as fileRepository
 import labstep.generic.entity.repository as entityRepository
+from labstep.generic.entityList.model import EntityList
 from labstep.service.helpers import handleDate, handleString
 from labstep.entities.metadata.model import Metadata, FIELDS, ALLOWED_FIELDS
 
@@ -11,6 +12,8 @@ from labstep.entities.metadata.model import Metadata, FIELDS, ALLOWED_FIELDS
 def getMetadata(entity, count=1000, extraParams={}):
     if hasattr(entity, 'metadata_thread') is False:
         entity.update()
+    if 'metadatas' in entity.metadata_thread:
+        return EntityList(entity.metadata_thread['metadatas'], Metadata, entity.__user__)
     params = {
         "metadata_thread_id": entity.metadata_thread["id"], **extraParams}
     return entityRepository.getEntities(
