@@ -43,7 +43,7 @@ class ProtocolMaterial(Entity):
             protocol_materials = exp_protocol.getMaterials()
             protocol_materials[0].edit(value=1.7, units='ml')
         """
-        from labstep.entities.protocolMaterial.repository import protocolMaterialRepository
+        import labstep.entities.protocolMaterial.repository as protocolMaterialRepository
 
         return protocolMaterialRepository.editProtocolMaterial(self,
                                                                name=name,
