@@ -37,7 +37,7 @@ class ProtocolTimer(Entity):
             protocol_timers[0].edit(name='New Timer Name',
                                     minutes=1, seconds=17)
         """
-        from labstep.generic.entity.repository import entityRepository
+        import labstep.generic.entity.repository as entityRepository
 
         params = {"name": name, **extraParams}
 
