@@ -47,7 +47,7 @@ class Tag(Entity):
             # Select the tag by using python index.
             tags[1].edit(name='A New Tag Name')
         """
-        from labstep.entities.tag.repository import tagRepository
+        import labstep.entities.tag.repository as tagRepository
 
         return tagRepository.editTag(self, name, extraParams=extraParams)
 
@@ -65,6 +65,6 @@ class Tag(Entity):
         tag
             An object representing the tag to delete.
         """
-        from labstep.entities.tag.repository import tagRepository
+        import labstep.entities.tag.repository as tagRepository
 
         return tagRepository.deleteTag(self)
