@@ -288,6 +288,35 @@ class Workspace(Entity):
             self.__user__, count, search_query, extraParams=extraParams
         )
 
+    def getResourceItems(self, count=100, search_query=None, extraParams={}):
+        """
+        Retrieve a list of ResourceItems in a workspace on Labstep.
+
+        Parameters
+        ----------
+        count (int)
+            The number of ResourceItems to retrieve.
+        search_query (str)
+            Search for ResourceItems with this 'name'.
+
+        Returns
+        -------
+        List[:class:`~labstep.entities.resourceItem.model.ResourceItem`]
+            A list of ResourceItem objects.
+
+        Example
+        -------
+        ::
+
+            entity = user.getResourceItems(search_query='batch #5')
+        """
+        import labstep.entities.resourceItem.repository as resourceItemRepository
+        extraParams = {"group_id": self.id, **extraParams}
+
+        return resourceItemRepository.getResourceItems(
+            self.__user__, count=count, search_query=search_query, extraParams=extraParams
+        )
+
     def getOrderRequests(
         self, count=100, name=None, status=None, tag_id=None, extraParams={}
     ):
