@@ -58,6 +58,15 @@ def getTime():
     return timestamp
 
 
+def formatDate(date, time=True):
+    if date is None:
+        return None
+
+    format = '%Y-%m-%d %H:%M:%S' if time else '%Y-%m-%d'
+
+    return datetime.strptime(date, '%Y-%m-%dT%H:%M:%S+00:00').strftime(format)
+
+
 def handleDate(date):
     """
     Returns
